@@ -4,25 +4,6 @@ library(stringr)
 library(glue)
 library(rvest)
 
-find_nodes <- function(md, node) {
-  md %>%
-    md_convert() %>%
-    read_html() %>%
-    html_nodes(node)
-}
-
-expect_empty <- function(object) {
-  expect_true(length(object) == 0)
-}
-
-expect_full <- function(object) {
-  expect_true(length(object) != 0)
-}
-
-expect_nchar <- function(object, n) {
-  expect_true(nchar(object) == n)
-}
-
 test_that("md_paragraph creates two simple paragraphs (ex. 189)", {
   # https://github.github.com/gfm/#example-189
   text <- c("aaa", "bbb")
