@@ -4,13 +4,6 @@ library(stringr)
 library(rvest)
 library(glue)
 
-expect_empty <- function(object) {
-  expect_true(length(object) == 0)
-}
-expect_full <- function(object) {
-  expect_true(length(object) != 0)
-}
-
 test_that("md_escape prepends ASCII punctuation with a backslash (ex. 308)", {
   # https://github.github.com/gfm/#example-308
   ascii_punct <- as_glue("!\"#$%&'()*+,-./:;<=>?@[]^_`{|}~")
