@@ -3,7 +3,6 @@ library(gluedown)
 library(stringr)
 library(rvest)
 library(knitr)
-library(httr)
 library(glue)
 
 test_that("md_issue creates GitHub auto-link URL", {
@@ -13,13 +12,6 @@ test_that("md_issue creates GitHub auto-link URL", {
   expect_equal(convert, url)
 })
 
-test_that("md_issue creates a URL that exists", {
-  issue <- md_issue("kiernann/gluedown", 1)
-  convert <- str_c("https://github.com/", str_replace(issue, "#", "/issues/"))
-  status <- status_code(GET(convert))
-  expect_equal(status, 200)
-})
-
 test_that("md_issue returns error without issue number", {
   expect_error(md_issue("kiernann/gluedown", "one"))
 })
